@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2006-2007 Zope Corporation and Contributors.
+# Copyright (c) 2006-2007 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -18,7 +18,6 @@ classes they define each typically inherit from one of the base classes
 provided here.
 
 """
-import persistent
 import simplejson
 
 import zope.location
@@ -30,155 +29,23 @@ from zope.publisher.interfaces import NotFound
 from zope.publisher.interfaces.browser import IBrowserPublisher
 from zope.publisher.interfaces.http import IHTTPRequest
 from zope.publisher.publish import mapply
-from zope.annotation.interfaces import IAttributeAnnotatable
-
-from zope.app.publisher.browser import getDefaultViewName
-from zope.app.container.btree import BTreeContainer
-from zope.app.container.contained import Contained
-from zope.app.container.interfaces import IReadContainer, IObjectAddedEvent
-from zope.app.container.interfaces import IOrderedContainer
-from zope.app.container.contained import notifyContainerModified
-from persistent.list import PersistentList
-from zope.app.component.site import SiteManagerContainer
-from zope.app.component.site import LocalSiteManager
+from zope.publisher.defaultview import getDefaultViewName
+from zope.container.interfaces import IReadContainer
 
 import grok
-import z3c.flashmessage.interfaces
 import martian.util
 
 import grokcore.view
+import grokcore.site
+import grokcore.message
 from grok import interfaces, util
 
-
-class Model(Contained, persistent.Persistent):
-    # XXX Inheritance order is important here. If we reverse this,
-    # then containers can't be models anymore because no unambigous MRO
-    # can be established.
-    """The base class for models in Grok applications.
-
-    When an application class inherits from `grok.Model`, it gains the
-    ability to persist itself in the Zope object database along with all
-    of its attributes, and to remember the container in which it has
-    been placed (its "parent") so that its URL can be computed.  It also
-    inherits the `IContext` marker interface, which can make it the
-    default context for views in its module; the rule is that if a
-    module contains `grok.View` classes or other adapters that do not
-    define a `grok.context()`, but the module also defines exactly one
-    class that provides the `IContext` interface, then that class will
-    automatically be made the `grok.context()` of each of the views.
-
-    """
-    interface.implements(IAttributeAnnotatable, interfaces.IContext)
+# BBB this is for import backward compatibility.
+from grokcore.json import JSON
+from grokcore.content import Model, Container, OrderedContainer
 
 
-class Container(BTreeContainer):
-    """The base class for containers in Grok applications.
-
-    When an application class inherits from `grok.Container`, it not
-    only has the features of a `grok.Model` (persistance, location, and
-    the ability to serve as a default context for other classes), but it
-    also behaves like a persistent dictionary.  To store items inside a
-    container, simply use the standard Python getitem/setitem protocol::
-
-        mycontainer['counter'] = 72
-        mycontainer['address'] = mymodel
-        mycontainer['subfolder'] = another_container
-
-    By default, the URL of each item inside a container is the
-    container's own URL followed by a slash and the key (like 'counter'
-    or 'address') under which that item has been stored.
-
-    """
-    interface.implements(IAttributeAnnotatable, interfaces.IContainer)
-
-
-class OrderedContainer(Container):
-    """A Grok container that remembers the order of its items.
-
-    This straightforward extension of the basic `grok.Container`
-    remembers the order in which items have been inserted, so that
-    `keys()`, `values()`, `items()`, and iteration across the container
-    can all return the items in the order they were inserted.  The only
-    way of changing the order is to call the `updateOrder()` method.
-
-    """
-    interface.implements(IOrderedContainer)
-
-    def __init__(self):
-        super(OrderedContainer, self).__init__()
-        self._order = PersistentList()
-
-    def keys(self):
-        # Return a copy of the list to prevent accidental modifications.
-        return self._order[:]
-
-    def __iter__(self):
-        return iter(self.keys())
-
-    def values(self):
-        return (self[key] for key in self._order)
-
-    def items(self):
-        return ((key, self[key]) for key in self._order)
-
-    def __setitem__(self, key, object):
-        foo = self.has_key(key)
-        # Then do whatever containers normally do.
-        super(OrderedContainer, self).__setitem__(key, object)
-        if not foo:
-            self._order.append(key)
-
-    def __delitem__(self, key):
-        # First do whatever containers normally do.
-        super(OrderedContainer, self).__delitem__(key)
-        self._order.remove(key)
-
-    def updateOrder(self, order):
-        """Impose a new order on the items in this container.
-
-        Items in this container are, by default, returned in the order
-        in which they were inserted.  To change the order, provide an
-        argument to this method that is a sequence containing every key
-        already in the container, but in a new order.
-
-        """
-        if set(order) != set(self._order):
-            raise ValueError("Incompatible key set.")
-
-        self._order = PersistentList()
-        self._order.extend(order)
-        notifyContainerModified(self)
-
-
-class Site(SiteManagerContainer):
-    """Mixin for creating sites in Grok applications.
-
-    When an application `grok.Model` or `grok.Container` also inherits
-    from `grok.Site`, then it can additionally support the registration
-    of local Component Architecture entities like `grok.LocalUtility`
-    and `grok.Indexes` objects; see those classes for more information.
-
-    """
-
-
-@component.adapter(Site, IObjectAddedEvent)
-def addSiteHandler(site, event):
-    """Add a local site manager to a Grok site object upon its creation.
-
-    Grok registers this function so that it gets called each time a
-    `grok.Site` instance is added to a container.  It creates a local
-    site manager and installs it on the newly created site.
-
-    """
-    sitemanager = LocalSiteManager(site)
-    # LocalSiteManager creates the 'default' folder in its __init__.
-    # It's not needed anymore in new versions of Zope 3, therefore we
-    # remove it
-    del sitemanager['default']
-    site.setSiteManager(sitemanager)
-
-
-class Application(Site):
+class Application(grokcore.site.Site):
     """Mixin for creating Grok application objects.
 
     When a `grok.Container` (or a `grok.Model`, though most developers
@@ -192,29 +59,6 @@ class Application(Site):
     interface.implements(interfaces.IApplication)
 
 
-class LocalUtility(Model):
-    """The base class for local utilities in Grok applications.
-
-    Although application developers can create local utilies without
-    actually subclassing `grok.LocalUtility`, they gain three benefits
-    from doing so.  First, their code is more readable because their
-    classes "look like" local utilities to casual readers.  Second,
-    their utility will know how to persist itself to the Zope database,
-    which means that they can set its object attributes and know that
-    the values are getting automatically saved.  Third, they can omit
-    the `grok.provides()` directive naming the interface that the
-    utility provides, if their class only `grok.implements()` a single
-    interface (unless the interface is one that the `grok.LocalUtility`
-    already implements, in which case Grok cannot tell them apart, and
-    `grok.provides()` must be used explicitly anyway).
-
-    """
-
-
-class Annotation(persistent.Persistent):
-    """The base class for annotation classes in Grok applications."""
-
-
 class View(grokcore.view.View):
     """The base class for views with templates in Grok applications.
 
@@ -287,22 +131,13 @@ class View(grokcore.view.View):
     """
     interface.implements(interfaces.IGrokView)
 
-    def application_url(self, name=None):
+    def application_url(self, name=None, data=None):
         """Return the URL of the nearest enclosing `grok.Application`."""
-        obj = self.context
-        while obj is not None:
-            if isinstance(obj, Application):
-                return self.url(obj, name)
-            obj = obj.__parent__
-        raise ValueError("No application found.")
+        return util.application_url(self.request, self.context, name, data)
 
     def flash(self, message, type='message'):
         """Send a short message to the user."""
-        # XXX this has no tests or documentation, anywhere
-        source = component.getUtility(
-            z3c.flashmessage.interfaces.IMessageSource, name='session')
-        source.send(message, type)
-
+        grokcore.message.send(message, type=type, name='session')
 
 
 class Form(grokcore.formlib.Form, View):
@@ -336,7 +171,13 @@ class EditForm(grokcore.formlib.EditForm, View):
     interface.implements(interfaces.IGrokForm)
 
 
-class XMLRPC(object):
+class ViewishViewSupport(grokcore.view.ViewSupport):
+
+    def application_url(self, name=None, data=None):
+        return util.application_url(self.request, self.context, name, data)
+
+
+class XMLRPC(ViewishViewSupport):
     """Base class for XML-RPC endpoints in Grok applications.
 
     When an application creates a subclass of `grok.XMLRPC`, it is
@@ -363,30 +204,13 @@ class XMLRPC(object):
     """
 
 
-class REST(zope.location.Location):
+class REST(zope.location.Location, ViewishViewSupport):
     """Base class for REST views in Grok applications."""
     interface.implements(interfaces.IREST)
 
     def __init__(self, context, request):
         self.context = self.__parent__ = context
         self.request = request
-        self.body = request.bodyStream.getCacheStream().read()
-
-    @property
-    def response(self):
-        return self.request.response
-
-
-class JSON(BrowserPage):
-    """Base class for JSON views in Grok applications."""
-    interface.implements(interfaces.IGrokSecurityView)
-
-    def __call__(self):
-        view_name = self.__view_name__
-        method = getattr(self, view_name)
-        method_result = mapply(method, (), self.request)
-        self.request.response.setHeader('Content-Type', 'application/json')
-        return simplejson.dumps(method_result)
 
 
 class Traverser(object):
