@@ -1,6 +1,6 @@
 #############################################################################
 #
-# Copyright (c) 2007-2008 Zope Corporation and Contributors.
+# Copyright (c) 2007-2008 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -18,8 +18,8 @@ import sys
 from zope.interface import implements
 from zope.interface.interfaces import IMethod, IInterface
 
-from zope.app.catalog.field import FieldIndex
-from zope.app.catalog.text import TextIndex
+from zope.catalog.field import FieldIndex
+from zope.catalog.text import TextIndex
 from zc.catalog.catalogindex import SetIndex
 
 from martian.error import GrokError, GrokImportError
@@ -27,6 +27,7 @@ from martian.util import frame_is_class
 
 from grok.interfaces import IIndexDefinition
 
+
 class IndexDefinition(object):
     """The definition of a particular index in a `grok.Indexes` class.
 
@@ -82,20 +83,23 @@ class IndexDefinition(object):
             call = IMethod.providedBy(method)
         else:
             call = callable(getattr(context, field_name, None))
-            context = None # no interface lookup
+            context = None  # no interface lookup
         catalog[name] = self.index_class(field_name=field_name,
                                          interface=context,
                                          field_callable=call,
                                          *self._args, **self._kw)
 
+
 class Field(IndexDefinition):
     """A `grok.Indexes` index that matches against an entire field."""
     index_class = FieldIndex
 
+
 class Text(IndexDefinition):
     """A `grok.Indexes` index supporting full-text searches of a field."""
     index_class = TextIndex
 
+
 class Set(IndexDefinition):
     """A `grok.Indexes` index supporting keyword searches of a field."""
     index_class = SetIndex
