@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2006-2007 Zope Corporation and Contributors.
+# Copyright (c) 2006-2007 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -15,13 +15,17 @@
 """
 from zope import interface
 from zope.interface.interfaces import IInterface
+from zope.component.interfaces import IObjectEvent
 from zope.publisher.interfaces.http import IHTTPRequest
-from zope.app.container.interfaces import IContainer as IContainerBase
+from zope.container.interfaces import IContainer as IContainerBase
 
 # Expose interfaces from grokcore.* packages as well:
+import grokcore.annotation.interfaces
 import grokcore.component.interfaces
 import grokcore.formlib.interfaces
+import grokcore.json.interfaces
 import grokcore.security.interfaces
+import grokcore.site.interfaces
 import grokcore.view.interfaces
 import grokcore.viewlet.interfaces
 
@@ -29,19 +33,18 @@ from grokcore.component.interfaces import IContext
 from grokcore.component.interfaces import IGrokErrors
 
 
-class IGrokBaseClasses(grokcore.component.interfaces.IBaseClasses,
+class IGrokBaseClasses(grokcore.annotation.interfaces.IBaseClasses,
+                       grokcore.component.interfaces.IBaseClasses,
                        grokcore.security.interfaces.IBaseClasses,
-                       grokcore.view.interfaces.IBaseClasses):
+                       grokcore.site.interfaces.IBaseClasses,
+                       grokcore.view.interfaces.IBaseClasses,
+                       grokcore.json.interfaces.IBaseClasses):
     Model = interface.Attribute("Base class for persistent content objects "
                                 "(models).")
     Container = interface.Attribute("Base class for containers.")
     OrderedContainer = interface.Attribute("Base class for ordered containers.")
-    Site = interface.Attribute("Mixin class for sites.")
     Application = interface.Attribute("Base class for applications.")
-    Annotation = interface.Attribute("Base class for persistent annotations.")
-    LocalUtility = interface.Attribute("Base class for local utilities.")
     XMLRPC = interface.Attribute("Base class for XML-RPC methods.")
-    JSON = interface.Attribute("Base class for JSON methods.")
     REST = interface.Attribute("Base class for REST views.")
     Traverser = interface.Attribute("Base class for custom traversers.")
     Indexes = interface.Attribute("Base class for catalog index definitions.")
@@ -50,23 +53,9 @@ class IGrokBaseClasses(grokcore.component.interfaces.IBaseClasses,
 
 class IGrokDirectives(grokcore.component.interfaces.IDirectives,
                       grokcore.security.interfaces.IDirectives,
+                      grokcore.site.interfaces.IDirectives,
                       grokcore.view.interfaces.IDirectives):
 
-    def local_utility(factory, provides=None, name=u'',
-                      setup=None, public=False, name_in_container=None):
-        """Register a local utility.
-
-        factory - the factory that creates the local utility
-        provides - the interface the utility should be looked up with
-        name - the name of the utility
-        setup - a callable that receives the utility as its single argument,
-                it is called after the utility has been created and stored
-        public - if False, the utility will be stored below ++etc++site
-                 if True, the utility will be stored directly in the site.
-                 The site should in this case be a container.
-        name_in_container - the name to use for storing the utility
-        """
-
     def permissions(permissions):
         """Specify the permissions that comprise a role.
         """
@@ -78,7 +67,6 @@ class IGrokDirectives(grokcore.component.interfaces.IDirectives,
         """
 
 
-
 class IGrokEvents(interface.Interface):
 
     IObjectCreatedEvent = interface.Attribute("")
@@ -111,10 +99,16 @@ class IGrokEvents(interface.Interface):
 
     IBeforeTraverseEvent = interface.Attribute("")
 
-class IGrokAPI(grokcore.security.interfaces.IGrokcoreSecurityAPI,
+    IApplicationInitializedEvent = interface.Attribute("")
+
+    ApplicationInitializedEvent = interface.Attribute("")
+
+
+class IGrokAPI(grokcore.formlib.interfaces.IGrokcoreFormlibAPI,
+               grokcore.security.interfaces.IGrokcoreSecurityAPI,
+               grokcore.site.interfaces.IGrokcoreSiteAPI,
                grokcore.view.interfaces.IGrokcoreViewAPI,
                grokcore.viewlet.interfaces.IGrokcoreViewletAPI,
-               grokcore.formlib.interfaces.IGrokcoreFormlibAPI,
                IGrokBaseClasses, IGrokDirectives,
                IGrokEvents, IGrokErrors):
 
@@ -153,6 +147,8 @@ class IGrokAPI(grokcore.security.interfaces.IGrokcoreSecurityAPI,
     def getSite():
         """Get the current site."""
 
+    def getApplication():
+        """Return the nearest enclosing `grok.Application`."""
 
     IRESTSkinType = interface.Attribute('The REST skin type')
 
@@ -183,6 +179,7 @@ class IREST(interface.Interface):
     body = interface.Attribute(
         """The text of the request body.""")
 
+
 class IApplication(interface.Interface):
     """Marker-interface for grok application factories.
 
@@ -190,6 +187,7 @@ class IApplication(interface.Interface):
     provide a list of grokked applications.
     """
 
+
 class IIndexDefinition(interface.Interface):
     """Define an index for grok.Indexes.
     """
@@ -201,27 +199,28 @@ class IIndexDefinition(interface.Interface):
         index for interface or class context.
         """
 
+
 class IRESTLayer(IHTTPRequest):
     """REST-specific Request functionality.
 
     Base Interfaces for defining REST-layers.
     """
 
+
 class IRESTSkinType(IInterface):
     """Skin type for REST requests.
     """
 
+
 class IContainer(IContext, IContainerBase):
     """A Grok container.
     """
 
-class IGrokSecurityView(interface.Interface):
-    """A view treated special by the Grok publisher.
 
-    Views that provide this interface are treated more generously by
-    the Grok publisher, as they are allowed to use attributes, which
-    are not covered by permission setttings.
+class IApplicationInitializedEvent(IObjectEvent):
+    """A Grok Application has been created with success and is now ready
+    to be used.
 
-    `grok.Permission` and `grok.require` settings however, will be
-    applied to such views.
-    """
+    This event can be used to trigger the creation of contents or other tasks
+    that require the application to be fully operational : utilities installed
+    and indexes created in the catalog."""
