@@ -1,6 +1,6 @@
 #############################################################################
 #
-# Copyright (c) 2006-2007 Zope Corporation and Contributors.
+# Copyright (c) 2006-2007 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -24,51 +24,45 @@ of a Grok-based web application.
 import zope.component.interface
 from zope import interface, component
 from zope.interface.interface import InterfaceClass
-from zope.publisher.interfaces.browser import (IDefaultBrowserLayer,
-                                               IBrowserPublisher)
+from zope.publisher.interfaces.browser import IBrowserPublisher
 from zope.publisher.interfaces.http import IHTTPRequest
 
 from zope.publisher.interfaces.xmlrpc import IXMLRPCRequest
 from zope.securitypolicy.interfaces import IRole
 from zope.securitypolicy.rolepermission import rolePermissionManager
 
-from zope.annotation.interfaces import IAnnotations
-
-from zope.app.publisher.xmlrpc import MethodPublisher
-from zope.app.container.interfaces import IContainer
-from zope.app.container.interfaces import INameChooser
-from zope.app.container.contained import contained
-
-from zope.app.intid import IntIds
-from zope.app.intid.interfaces import IIntIds
-from zope.app.catalog.catalog import Catalog
-from zope.app.catalog.interfaces import ICatalog
-
+from zope.i18nmessageid import Message
+from zope.intid import IntIds
+from zope.intid.interfaces import IIntIds
+from zope.catalog.catalog import Catalog
+from zope.catalog.interfaces import ICatalog
+from zope.location import Location
 from zope.exceptions.interfaces import DuplicationError
+from zope.publisher.xmlrpc import XMLRPCView
 
 import martian
 from martian.error import GrokError
-from martian import util
 
 import grok
 from grok import components
-from grok.util import make_checker
 from grok.interfaces import IRESTSkinType
 
+import grokcore.site.interfaces
 from grokcore.security.meta import PermissionGrokker
 
-from grokcore.view.meta.views import default_fallback_to_name
+from grokcore.view import make_checker
 
 
-def default_annotation_provides(factory, module, **data):
-    base_interfaces = interface.implementedBy(grok.Annotation)
-    factory_interfaces = interface.implementedBy(factory)
-    real_interfaces = list(factory_interfaces - base_interfaces)
-    util.check_implements_one_from_list(real_interfaces, factory)
-    return real_interfaces[0]
+class MethodPublisher(XMLRPCView, Location):
+    """Copied from zope.app.publisher.xmlrpc to get rid of that dependency.
+    """
+    def __getParent(self):
+        return hasattr(self, '_parent') and self._parent or self.context
 
-def default_annotation_name(factory, module, **data):
-    return factory.__module__ + '.' + factory.__name__
+    def __setParent(self, parent):
+        self._parent = parent
+
+    __parent__ = property(__getParent, __setParent)
 
 
 class XMLRPCGrokker(martian.MethodGrokker):
@@ -96,8 +90,7 @@ class XMLRPCGrokker(martian.MethodGrokker):
         # views have a location
         method_view = type(
             factory.__name__, (factory, MethodPublisher),
-            {'__call__': method}
-            )
+            {'__call__': method})
 
         adapts = (context, IXMLRPCRequest)
         config.action(
@@ -142,8 +135,7 @@ class RESTGrokker(martian.MethodGrokker):
 
         method_view = type(
             factory.__name__, (factory,),
-            {'__call__': method }
-            )
+            {'__call__': method})
 
         adapts = (context, layer)
         config.action(
@@ -161,6 +153,7 @@ class RESTGrokker(martian.MethodGrokker):
 
 _restskin_not_used = object()
 
+
 class RestskinInterfaceDirectiveGrokker(martian.InstanceGrokker):
     """Grokker for interfaces providing the `grok.restskin()` directive.
 
@@ -193,55 +186,13 @@ class RestskinInterfaceDirectiveGrokker(martian.InstanceGrokker):
                 "required for interfaces that are used as layers and are to "
                 "be registered as a restskin."
                 % (interface.__identifier__, interface.__identifier__),
-                interface
-                )
+                interface)
+
         config.action(
             discriminator=('restprotocol', restskin),
             callable=zope.component.interface.provideInterface,
-            args=(restskin, interface, IRESTSkinType)
-            )
-        return True
+            args=(restskin, interface, IRESTSkinType))
 
-
-class JSONGrokker(martian.MethodGrokker):
-    """Grokker for methods of a `grok.JSON` subclass.
-
-    When an application defines a `grok.JSON` view, we do not actually
-    register the view with the Component Architecture.  Instead, we grok
-    each of its methods separately, placing them each inside of a new
-    class that we create on-the-fly by calling `type()`.  We make each
-    method the `__call__()` method of its new class, since that is how
-    Zope always invokes views.  And it is this new class that is then
-    made the object of the two configuration actions that we schedule:
-    one to activate it as a JSON adapter for the context, and the other
-    to prepare a security check for the adapter.
-
-    """
-    martian.component(grok.JSON)
-    martian.directive(grok.context)
-    martian.directive(grok.require, name='permission')
-    martian.directive(grok.layer, default=IDefaultBrowserLayer)
-
-    def execute(
-            self, factory, method, config, context, permission, layer, **kw):
-        # Create a new class with a __view_name__ attribute so the
-        # JSON class knows what method to call.
-        method_view = type(
-            factory.__name__, (factory,),
-            {'__view_name__': method.__name__}
-            )
-        adapts = (context, layer)
-        name = method.__name__
-        config.action(
-            discriminator=('adapter', adapts, interface.Interface, name),
-            callable=component.provideAdapter,
-            args=(method_view, adapts, interface.Interface, name),
-            )
-        config.action(
-            discriminator=('protectName', method_view, '__call__'),
-            callable=make_checker,
-            args=(factory, method_view, permission),
-            )
         return True
 
 
@@ -260,90 +211,8 @@ class TraverserGrokker(martian.ClassGrokker):
         return True
 
 
-class SiteGrokker(martian.ClassGrokker):
-    """Grokker for subclasses of `grok.Site`."""
-    martian.component(grok.Site)
-    martian.priority(500)
-    martian.directive(grok.local_utility, name='infos')
-
-    def execute(self, factory, config, infos, **kw):
-        if not infos:
-            return False
-
-        infos = infos.values()
-        for info in infos:
-            if info.public and not IContainer.implementedBy(factory):
-                raise GrokError(
-                    "Cannot set public to True with grok.local_utility as "
-                    "the site (%r) is not a container." %
-                    factory, factory)
-
-        # Store the list of info objects in their "natural" order on the
-        # site class. They will be picked up by a subscriber doing the
-        # actual registrations in definition order.
-        factory.__grok_utilities_to_install__ = sorted(infos)
-        adapts = (factory, grok.IObjectAddedEvent)
-
-        config.action(
-            discriminator=None,
-            callable=component.provideHandler,
-            args=(localUtilityRegistrationSubscriber, adapts),
-            )
-        return True
-
-
-def localUtilityRegistrationSubscriber(site, event):
-    """A subscriber that fires to set up local utilities.
-    """
-    installed = getattr(site, '__grok_utilities_installed__', False)
-    if installed:
-        return
-
-    for info in getattr(site.__class__, '__grok_utilities_to_install__', []):
-        setupUtility(site, info.factory(), info.provides, name=info.name,
-                     name_in_container=info.name_in_container,
-                     public=info.public, setup=info.setup)
-
-    # we are done. If this subscriber gets fired again, we therefore
-    # do not register utilities anymore
-    site.__grok_utilities_installed__ = True
-
-
-def setupUtility(site, utility, provides, name=u'',
-                 name_in_container=None, public=False, setup=None):
-    """Set up a utility in a site.
-
-    site - the site to set up the utility in
-    utility - the utility to set up
-    provides - the interface the utility should be registered with
-    name - the name the utility should be registered under, default
-      the empty string (no name)
-    name_in_container - if given it will be used to add the utility
-      object to its container. Otherwise a name will be made up
-    public - if False, the utility will be stored in the site manager. If
-      True, the utility will be storedin the site (it is assumed the
-      site is a container)
-    setup - if not None, it will be called with the utility as its first
-       argument. This function can then be used to further set up the
-       utility.
-    """
-    site_manager = site.getSiteManager()
-
-    if not public:
-        container = site_manager
-    else:
-        container = site
-
-    if name_in_container is None:
-        name_in_container = INameChooser(container).chooseName(
-            utility.__class__.__name__, utility)
-    container[name_in_container] = utility
-
-    if setup is not None:
-        setup(utility)
-
-    site_manager.registerUtility(utility, provided=provides,
-                                 name=name)
+def default_fallback_to_name(factory, module, name, **data):
+    return name
 
 
 class RoleGrokker(martian.ClassGrokker):
@@ -369,7 +238,11 @@ class RoleGrokker(martian.ClassGrokker):
                 "grok.name to specify one.", factory)
         # We can safely convert to unicode, since the directives makes sure
         # it is either unicode already or ASCII.
-        role = factory(unicode(name), unicode(title), unicode(description))
+        if not isinstance(title, Message):
+            title = unicode(title)
+        if not isinstance(description, Message):
+            description = unicode(description)
+        role = factory(unicode(name), title, description)
 
         config.action(
             discriminator=('utility', IRole, name),
@@ -386,39 +259,6 @@ class RoleGrokker(martian.ClassGrokker):
         return True
 
 
-class AnnotationGrokker(martian.ClassGrokker):
-    """Grokker for components subclassed from `grok.Annotation`."""
-    martian.component(grok.Annotation)
-    martian.directive(grok.context, name='adapter_context')
-    martian.directive(grok.provides, get_default=default_annotation_provides)
-    martian.directive(grok.name, get_default=default_annotation_name)
-
-    def execute(self, factory, config, adapter_context, provides, name, **kw):
-        @component.adapter(adapter_context)
-        @interface.implementer(provides)
-        def getAnnotation(context):
-            annotations = IAnnotations(context)
-            try:
-                result = annotations[name]
-            except KeyError:
-                result = factory()
-                annotations[name] = result
-
-            # Containment has to be set up late to allow containment
-            # proxies to be applied, if needed. This does not trigger
-            # an event and is idempotent if containment is set up
-            # already.
-            contained_result = contained(result, context, name)
-            return contained_result
-
-        config.action(
-            discriminator=('adapter', adapter_context, provides, ''),
-            callable=component.provideAdapter,
-            args=(getAnnotation,),
-            )
-        return True
-
-
 class ApplicationGrokker(martian.ClassGrokker):
     """Grokker for Grok application classes."""
     martian.component(grok.Application)
@@ -516,6 +356,8 @@ class IndexesSetupSubscriber(object):
         if catalog is not None:
             return catalog
         catalog = Catalog()
+        setupUtility = component.getUtility(
+            grokcore.site.interfaces.IUtilityInstaller)
         setupUtility(site, catalog, ICatalog, name=self.catalog_name)
         return catalog
 
@@ -527,6 +369,7 @@ class IndexesSetupSubscriber(object):
         if intids is not None:
             return intids
         intids = IntIds()
+        setupUtility = component.getUtility(
+            grokcore.site.interfaces.IUtilityInstaller)
         setupUtility(site, intids, IIntIds)
         return intids
-
