@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2007 Zope Corporation and Contributors.
+# Copyright (c) 2007 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -14,30 +14,11 @@
 """Grok test helpers
 """
 import sys
-import os.path
-import z3c.testsetup
 from zope.configuration.config import ConfigurationMachine
 from grokcore.component import zcml
 # Provide this import here for BBB reasons:
 from grokcore.component.testing import grok_component
 
-class GrokTestCollector(z3c.testsetup.TestCollector):
-
-    def initialize(self):
-        # inject the grok ftesting ZCML as fallback...
-        if 'zcml_config' in self.settings.keys():
-            return
-        pkg_path = os.path.dirname(self.package.__file__)
-        if os.path.isfile(os.path.join(pkg_path, 'ftesting.zcml')):
-            return
-        self.settings['zcml_config'] = os.path.join(
-            os.path.dirname(__file__), 'ftesting.zcml')
-        if 'layer_name' in self.settings.keys():
-            return
-        self.settings['layer_name'] = 'GrokFunctionalLayer'
-
-def register_all_tests(pkg, *args, **kw):
-    return GrokTestCollector(pkg, *args, **kw)
 
 def grok(module_name):
     config = ConfigurationMachine()
@@ -47,10 +28,13 @@ def grok(module_name):
     zcml.do_grok('grokcore.view.templatereg', config)
     zcml.do_grok('grokcore.viewlet.meta', config)
     zcml.do_grok('grokcore.formlib.meta', config)
+    zcml.do_grok('grokcore.annotation.meta', config)
+    zcml.do_grok('grokcore.site.meta', config)
     zcml.do_grok('grok.meta', config)
     zcml.do_grok(module_name, config)
     config.execute_actions()
 
+
 def warn(message, category=None, stacklevel=1):
     """Intended to replace warnings.warn in tests.
 
